@@ -25,14 +25,14 @@
  */
 
 /*- Compiler specifics -*/
-// #ifdef __clang__
+#ifdef __clang__
 // #pragma clang diagnostic ignored "-Wshorten-64-to-32"
-// #endif
+#endif
 
-// #if defined(_MSC_VER)
-// #  pragma warning(disable : 4244)
-// #  pragma warning(disable : 4127)    /* C4127 : Condition expression is constant */
-// #endif
+#if defined(_MSC_VER)
+#  pragma warning(disable : 4244)
+#  pragma warning(disable : 4127)    /* C4127 : Condition expression is constant */
+#endif
 
 
 /*- Dependencies -*/
